/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.task.field;

import java.awt.Color;
import java.io.Serializable;
import nl.cloudfarming.client.geoviewer.RangedLegendPalette;
import nl.cloudfarming.client.util.Gradient;
import nl.cloudfarming.client.util.UOM;

/**
 * Pallete for a {@link FieldTask}
 *
 * @author Merijn Zengers <Merijn.Zengers@gmail.nl>
 */
public class FieldTaskPalette extends RangedLegendPalette<Double> implements Serializable {

    public static final Color STEP_0 = new Color(0, 96, 255);
    public static final Color STEP_1 = new Color(0, 159, 255);
    public static final Color STEP_2 = new Color(0, 223, 255);
    public static final Color STEP_3 = new Color(32, 255, 223);
    public static final Color STEP_4 = new Color(96, 255, 159);
    public static final Color STEP_5 = new Color(159, 255, 96);
    public static final Color STEP_6 = new Color(223, 255, 32);
    public static final Color STEP_7 = new Color(255, 223, 0);
    public static final Color STEP_8 = new Color(255, 159, 0);
    public static final Color STEP_9 = new Color(255, 96, 0);
    
    private static final Color[] COLORS = new Color[]{STEP_0, STEP_1, STEP_2, STEP_3, STEP_4, STEP_5, STEP_6, STEP_7, STEP_8, STEP_9};
    private static final Gradient GRADIENT = Gradient.create(COLORS);

    public FieldTaskPalette(Double minValue, Double maxValue, UOM uom) {
        super(STEP_0, minValue, maxValue, uom);
    }
    
    @Override
    protected Color[] getColors() {
        return COLORS;
    }
    
    @Override
    protected Gradient getGradient() {
        return GRADIENT;
    }
}
