/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.task.field;

import java.awt.BorderLayout;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.util.HashMap;
import java.util.Map;
import javax.swing.Action;
import javax.swing.JComponent;
import nl.cloudfarming.client.task.Task;
import nl.cloudfarming.client.util.swing.ASBodyPanel;
import org.netbeans.core.spi.multiview.MultiViewElement;
import org.openide.awt.UndoRedo;
import org.openide.util.ImageUtilities;
import org.openide.util.Lookup;
import org.openide.util.NbBundle.Messages;
import org.openide.util.lookup.Lookups;
import org.openide.windows.TopComponent;

/**
 * Top component which displays something.
 */
@MultiViewElement.Registration(displayName = "#FieldTaskVisualElement_display_name",
iconBase = "nl/cloudfarming/client/task/field/to_do_list_checked_1.png",
mimeType = FieldTask.MIME_TYPE,
preferredID = "FieldTaskVisualElement",
position = 100,
persistenceType = TopComponent.PERSISTENCE_NEVER)
@Messages({
    "FieldTaskVisualElement_display_name=Task Context",
    "CTL_FieldTaskAction=FieldTask",
    "CTL_FieldTaskTopComponent=FieldTask Window",
    "HINT_FieldTaskTopComponent=This is a FieldTask window"
})
public final class FieldTaskVisualElement extends BaseFieldTaskElement implements PropertyChangeListener {
    
    private static final String TASK_ICON_PATH = "nl/cloudfarming/client/task/field/task32.png";
    private static final Map<FieldTask, FieldTaskVisualElement> OVERVIEW_FOR_TASK_MAP = new HashMap<>();
    private FieldTaskOverviewPanel panel;
    private ASBodyPanel panelDecorator;
    private Lookup lookup;

    /**
     * We need a constructor with a lookup for a MultiViewElement but we also
     * need to task in order to initialize the underlying panels. This
     * constructor accepts a lookup and uses the passed lookup to find an
     * ExportableTaskCapability object from which it can extract a task.
     *
     * @param lookup
     */
    public FieldTaskVisualElement(Lookup lookup) {
        super(lookup);
        this.lookup = lookup;
        init();
    }
    
    public FieldTaskVisualElement(FieldTask fieldTask) {
        super(Lookups.fixed(fieldTask));
        init();

    }
    
    public static FieldTaskVisualElement findInstance(FieldTask task) {
        FieldTaskVisualElement topComponent = OVERVIEW_FOR_TASK_MAP.get(task);
        if (topComponent == null) {
            topComponent = new FieldTaskVisualElement(task);
            OVERVIEW_FOR_TASK_MAP.put(task, topComponent);
        }
        return topComponent;
    }

    /**
     * This method is called from within the constructor to initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is always
     * regenerated by the Form Editor.
     */
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {
        
        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(this);
        this.setLayout(layout);
        layout.setHorizontalGroup(
                layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                .addGap(0, 400, Short.MAX_VALUE));
        layout.setVerticalGroup(
                layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                .addGap(0, 300, Short.MAX_VALUE));
    }// </editor-fold>//GEN-END:initComponents


    
    void writeProperties(java.util.Properties p) {
        // better to version settings since initial version as advocated at
        // http://wiki.apidesign.org/wiki/PropertyFiles
        p.setProperty("version", "1.0");
        // TODO store your settings
    }
    
    void readProperties(java.util.Properties p) {
        String version = p.getProperty("version");
        // TODO read your settings according to their version
    }
    
    @Override
    public JComponent getVisualRepresentation() {
        return panelDecorator;
    }
    
    @Override
    public Action[] getActions() {
        return new Action[0];
    }
    
    @Override
    public Lookup getLookup() {
        return lookup;
    }
    
    @Override
    public UndoRedo getUndoRedo() {
        return UndoRedo.NONE;
    }
    
    @Override
    public void propertyChange(PropertyChangeEvent evt) {
        if (evt.getPropertyName().equalsIgnoreCase(Task.PROP_NAME)) {
            updateName();
        }
    }
    
    @Override
    public int getPersistenceType() {
        return super.getPersistenceType();
    }

    private void init() {
        panel = new FieldTaskOverviewPanel();
        panel.setTask(fieldTask);
        
        panelDecorator = new ASBodyPanel(panel);
        panelDecorator.setTitle(fieldTask.getName());
        panelDecorator.setIcon(ImageUtilities.loadImageIcon(TASK_ICON_PATH, true));
        setLayout(new BorderLayout());
        add(panelDecorator);
        
        setName(fieldTask.getName());
        setToolTipText(Bundle.HINT_FieldTaskTopComponent());
        this.fieldTask.addPropertyChangeListener(this);
    }
}
